@@ -1,6 +1,14 @@
 # -*- coding: utf-8 -*-
+import sys
 import functools
 
+PY2 = sys.version_info[0] == 2
+
+if not PY2:
+    iteritems = lambda d: iter(d.items())
+else:
+    iteritems = lambda d: d.iteritems()
+
 
 class WebargsError(Exception):
     """Base class for all webargs-related errors."""
@@ -23,6 +31,10 @@ def _callable(obj):
         return obj
 
 
+def noop(x):
+    return x
+
+
 class Arg(object):
     """A request argument.
 
@@ -34,16 +46,17 @@ class Arg(object):
         defined) used for custom validation. Returns whether or not the
         value is valid.
     :param callable use: Callable used for converting or pre-processing the value.
+        Defaults to noop.
         Example: ``use=lambda s: s.lower()``
     :param str error: Custom error message to use if validation fails.
     """
     def __init__(self, type_=None, default=None, required=False,
                  validate=None, use=None, error=None):
-        self.type = type_
+        self.type = type_ or noop  # default to no type conversion
         self.default = default
         self.required = required
-        self.validate = _callable(validate)
-        self.use = _callable(use)
+        self.validate = _callable(validate) or (lambda x: True)
+        self.use = _callable(use) or noop
         self.error = error
 
     def validated(self, value):
@@ -54,17 +67,13 @@ class Arg(object):
         :raises: ValidationError if validation fails
         """
         ret = value
-        if self.type:
-            # First try to convert to self.type
-            try:
-                ret = self.type(value)
-            except ValueError as error:
-                raise ValidationError(self.error or error)
-        # Then call `use`
-        if self.use:
-            ret = self.use(ret)
+        # First convert the value
+        try:
+            ret = self.use(self.type(value))
+        except ValueError as error:
+            raise ValidationError(self.error or error)
         # Then call validation function
-        if self.validate and not self.validate(ret):
+        if not self.validate(ret):
             msg = 'Validator {0}({1}) is not True'.format(
                 self.validate.__name__, ret
             )
@@ -80,6 +89,8 @@ class Parser(object):
 
     Descendant classes must provide lower-level implementations for parsing
     different targets, e.g. ``parse_json``, ``parse_querystring``, etc.
+
+    :param tuple targets: Default targets to parse.
     """
 
     #: Maps target => method name
@@ -89,8 +100,12 @@ class Parser(object):
         'form': 'parse_form',
         'headers': 'parse_headers',
         'cookies': 'parse_cookies',
+        'files': 'parse_files',
     }
 
+    def __init__(self, targets=DEFAULT_TARGETS):
+        self.targets = targets
+
     def _validated_targets(self, targets):
         """Ensure that the given targets argument is valid.
 
@@ -106,7 +121,7 @@ class Parser(object):
             raise ValueError(msg)
         return targets
 
-    def parse_arg(self, name, argobj, req, targets=DEFAULT_TARGETS):
+    def parse_arg(self, name, argobj, req, targets=None):
         """Parse a single argument.
 
         :param str name: The name of the value.
@@ -117,7 +132,7 @@ class Parser(object):
         :return: The argument value.
         """
         value = None
-        for target in self._validated_targets(targets):
+        for target in self._validated_targets(targets or self.targets):
             method_name = self.TARGET_MAP.get(target, None)
             if method_name:
                 method = getattr(self, method_name)
@@ -134,19 +149,22 @@ class Parser(object):
                 raise ValidationError('Required parameter {0!r} not found.'.format(name))
         return value
 
-    def parse(self, argmap, req, targets=DEFAULT_TARGETS):
+    def parse(self, argmap, req, targets=None):
         """Main request parsing method.
 
         :param dict argmap: Dictionary of argname:Arg object pairs.
         :param req: The request object to parse.
         :param tuple targets: Where on the request to search for values.
             Can include one or more of ``('json', 'querystring', 'form',
-            'headers', 'cookies')``.
+            'headers', 'cookies', 'files')``.
         :return: A dictionary of parsed arguments
         """
         try:
-            return dict([(argname, self.parse_arg(argname, argobj, req, targets=targets))
-                    for argname, argobj in argmap.items()])
+            return dict(
+                (argname, self.parse_arg(argname, argobj, req,
+                    targets=targets or self.targets))
+                for argname, argobj in iteritems(argmap)
+            )
         except Exception as error:
             self.handle_error(error)
 
@@ -203,6 +221,12 @@ class Parser(object):
         """
         return None
 
+    def parse_files(self, req, name):
+        """Pull a file from the request or return ``None`` if the value file
+        cannot be found.
+        """
+        return None
+
     def handle_error(self, error):
         """Called if an error occurs while parsing args.
         """
